@@ -12,58 +12,13 @@ from baidupcs_py.commands.sifter import Sifter, sift
 from baidupcs_py.commands.download import USER_AGENT
 from baidupcs_py.commands.errors import CommandError
 from baidupcs_py.commands.display import display_blocked_remotepath
+from baidupcs_py.common.file_type import MEDIA_EXTS
 
 _print = print
 
 from rich import print
 
 
-MEDIA_EXTS = set(
-    [
-        ".wma",
-        ".wav",
-        ".mp3",
-        ".aac",
-        ".ra",
-        ".ram",
-        ".mp2",
-        ".ogg",
-        ".aif",
-        ".mpega",
-        ".amr",
-        ".mid",
-        ".midi",
-        ".m4a",
-        ".m4v",
-        ".wmv",
-        ".rmvb",
-        ".mpeg4",
-        ".mpeg2",
-        ".flv",
-        ".avi",
-        ".3gp",
-        ".mpga",
-        ".qt",
-        ".rm",
-        ".wmz",
-        ".wmd",
-        ".wvx",
-        ".wmx",
-        ".wm",
-        ".swf",
-        ".mpg",
-        ".mp4",
-        ".mkv",
-        ".mpeg",
-        ".mov",
-        ".mdf",
-        ".iso",
-        ".asf",
-        ".vob",
-    ]
-)
-
-
 def _with_media_ext(path: str) -> bool:
     ext = os.path.splitext(path)[-1].lower()
     if ext in MEDIA_EXTS:
@@ -239,7 +194,7 @@ def play_dir(
     local_server: str = "",
 ):
     remotepaths = api.list(remotedir)
-    remotepaths = sift(remotepaths, sifters)
+    remotepaths = sift(remotepaths, sifters, recursive=recursive)
 
     if shuffle:
         rg = random.Random(time.time())
@@ -259,21 +214,22 @@ def play_dir(
                 local_server=local_server,
             )
         else:  # is_dir
-            play_dir(
-                api,
-                rp.path,
-                sifters=sifters,
-                recursive=recursive,
-                from_index=from_index,
-                player=player,
-                player_params=player_params,
-                m3u8=m3u8,
-                quiet=quiet,
-                shuffle=shuffle,
-                ignore_ext=ignore_ext,
-                out_cmd=out_cmd,
-                local_server=local_server,
-            )
+            if recursive:
+                play_dir(
+                    api,
+                    rp.path,
+                    sifters=sifters,
+                    recursive=recursive,
+                    from_index=from_index,
+                    player=player,
+                    player_params=player_params,
+                    m3u8=m3u8,
+                    quiet=quiet,
+                    shuffle=shuffle,
+                    ignore_ext=ignore_ext,
+                    out_cmd=out_cmd,
+                    local_server=local_server,
+                )
 
 
 def play(
